@@ -8,7 +8,7 @@ package Device::BusPirate;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 
@@ -34,7 +34,7 @@ readonly_struct Reader => [qw( length future )];
 readonly_struct Alarm  => [qw( time future )];
 
 use constant BUS_PIRATE => $ENV{BUS_PIRATE} || "/dev/ttyUSB0";
-use constant PIRATE_DEBUG => $ENV{PIRATE_DEBUG};
+use constant PIRATE_DEBUG => $ENV{PIRATE_DEBUG} // 0;
 
 =head1 NAME
 
@@ -83,7 +83,9 @@ can then be chained using the C<then> method:
 
 =cut
 
-=head2 $pirate = Device::BusPirate->new( %args )
+=head2 new
+
+   $pirate = Device::BusPirate->new( %args )
 
 Returns a new C<Device::BusPirate> instance to communicate with the given
 device. Takes the following named arguments:
@@ -150,7 +152,7 @@ sub write
 sub read
 {
    my $self = shift;
-   my ( $n, $name ) = @_;
+   my ( $n, $name, $timeout ) = @_;
 
    push @{ $self->{readers} }, Reader( $n, my $f = $self->_new_future );
 
@@ -158,11 +160,13 @@ sub read
 
    return Future->wait_any(
       $f,
-      $self->sleep( 0.5 )->then_fail( "Timeout waiting for $name" ),
+      $self->sleep( $timeout // 0.5 )->then_fail( "Timeout waiting for $name" ),
    );
 }
 
-=head2 $pirate->sleep( $timeout )->get
+=head2 sleep
+
+   $pirate->sleep( $timeout )->get
 
 Returns a C<Future> that will become ready after the given timeout (in
 seconds), unless it is cancelled first.
@@ -190,7 +194,9 @@ sub sleep
    return $f;
 }
 
-=head2 @result = $pirate->enter_mutex( $code )->get
+=head2 enter_mutex
+
+   @result = $pirate->enter_mutex( $code )->get
 
 Acts as a mutex lock, to ensure only one block of code runs at once. Calls to
 C<enter_mutex> will be queued up; each C<$code> block will only be invoked
@@ -218,7 +224,9 @@ sub enter_mutex
       });
 }
 
-=head2 $mode = $pirate->enter_mode( $modename )->get
+=head2 enter_mode
+
+   $mode = $pirate->enter_mode( $modename )->get
 
 Switches the attached device into the given mode, and returns an object to
 represent that hardware mode to interact with. This will be an instance of a
@@ -260,7 +268,16 @@ sub enter_mode
    });
 }
 
-=head2 $chip = $pirate->mount_chip( $chipname, %opts )->get
+=head2 mount_chip
+
+   $chip = $pirate->mount_chip( $chipname, %opts )->get
+
+B<Note>: this method is now deprecated in favour of the L<Device::Chip>
+interface. This distribution provides a class,
+L<Device::Chip::Adapter::BusPirate>, suitable to connect an instance of the
+L<Device::Chip> interface to. Any previously-written Bus Pirate-specific
+chip driver classes should now be changed to target the generic
+L<Device::Chip> interface instead.
 
 Constructs a "chip" object; a helper designed to communicate with some
 particular hardware device (usually a specific chip) attached to the Bus
@@ -290,7 +307,9 @@ sub mount_chip
       ->then_done( $chip );
 }
 
-=head2 $pirate->start->get
+=head2 start
+
+   $pirate->start->get
 
 Starts binary IO mode on the F<Bus Pirate> device, enabling the module to
 actually communicate with it. Normally it is not necessary to call this method
@@ -303,7 +322,7 @@ sub start
    my $self = shift;
 
    Future->wait_any(
-      $self->read( 5, "start" )->then( sub {
+      $self->read( 5, "start", 2.5 )->then( sub {
          my ( $buf ) = @_;
          return Future->done( ( $self->{version} ) = $buf =~ m/^BBIO(\d)/ );
       }),
@@ -318,7 +337,9 @@ sub start
    );
 }
 
-=head2 $pirate->stop
+=head2 stop
+
+   $pirate->stop
 
 Stops binary IO mode on the F<Bus Pirate> device and returns it to user
 terminal mode. It may be polite to perform this at the end of a program to
