@@ -1,19 +1,27 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2014-2015 -- leonerd@leonerd.org.uk
 
 package Device::BusPirate::Chip;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head1 NAME
 
 C<Device::BusPirate::Chip> - base class for chip-specific adapters
 
+=head1 DEPRECATION
+
+B<Note>: this package and its entire module name heirarchy are now deprecated
+in favour of the L<Device::Chip> interface instead. Any existing chip
+implementations should be rewritten. They can continue to target the
+I<Bus Pirate> by using L<Device::Chip::Adapter::BusPirate>, but will therefore
+gain the ability to use any other implementation of L<Device::Chip::Adapter>.
+
 =head1 DESCRIPTION
 
 This base class is provided for implementations of chip-specific adapters, to
@@ -26,7 +34,9 @@ hardware attached to the Bus Pirate.
 
 =cut
 
-=head2 $chip = Device::BusPirate::Chip->new( $bp, %opts )
+=head2 new
+
+   $chip = Device::BusPirate::Chip->new( $bp, %opts )
 
 Constructs a new instance of the chip adapter. The first argument is the
 L<Device::BusPirate> object itself. The remaining arguments are not otherwise
@@ -48,7 +58,9 @@ sub new
 
 =cut
 
-=head2 $pirate = $chip->pirate
+=head2 pirate
+
+   $pirate = $chip->pirate
 
 Returns the L<Device::BusPirate> instance.
 
@@ -60,7 +72,9 @@ sub pirate
    return $self->{bp};
 }
 
-=head2 $mode = $chip->mode
+=head2 mode
+
+   $mode = $chip->mode
 
 Returns the C<Device::BusPirate::Mode> instance being used to communicate with
 this chip. Normally this method would be used directly by the implementation
@@ -74,7 +88,9 @@ sub mode
    return $self->{mode};
 }
 
-=head2 $chip = $chip->mount( $mode )->get
+=head2 mount
+
+   $chip = $chip->mount( $mode )->get
 
 Called by the C<mount_chip> method on the C<Device::BusPirate> object, this
 method is intended for implementation subclasses to perform any initial
@@ -110,7 +126,9 @@ foreach my $method (qw( power pullup aux )) {
 The following methods must be provided by specific implementations of this
 base class:
 
-=head2 $chipname = Device::BusPirate::Chip->CHIP
+=head2 CHIP
+
+   $chipname = Device::BusPirate::Chip->CHIP
 
 Returns the name for this chip; the name that must be passed to the
 C<mount_chip> method on C<Device::BusPirate> in order to request this
@@ -119,7 +137,9 @@ given by the hardware manufacturer to identify the chip. It does not need to
 be a valid Perl symbol; it may contain characters not normally allowed in
 symbol names.
 
-=head2 $modename = $chip->MODE
+=head2 MODE
+
+   $modename = $chip->MODE
 
 Called after construction, this method should return a mode name that will be
 used to communicate with the chip. Normally this would be a constant, hence
