@@ -8,7 +8,7 @@ package Device::BusPirate::Mode;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use constant {
    CONF_CS     => 0x01,
@@ -48,7 +48,9 @@ sub new
 
 =cut
 
-=head2 $pirate = $mode->pirate
+=head2 pirate
+
+   $pirate = $mode->pirate
 
 Returns the underlying L<Device::BusPirate> instance.
 
@@ -75,7 +77,9 @@ sub _start_mode_and_await
    });
 }
 
-=head2 $mode->power( $power )->get
+=head2 power
+
+   $mode->power( $power )->get
 
 Enable or disable the C<VREG> 5V and 3.3V power outputs.
 
@@ -88,7 +92,9 @@ sub power
    $self->_update_peripherals;
 }
 
-=head2 $mode->pullup( $pullup )->get
+=head2 pullup
+
+   $mode->pullup( $pullup )->get
 
 Enable or disable the IO pin pullup resistors from C<Vpu>. These are connected
 to the C<MISO>, C<CLK>, C<MOSI> and C<CS> pins.
@@ -102,7 +108,9 @@ sub pullup
    $self->_update_peripherals;
 }
 
-=head2 $mode->aux( $aux )->get
+=head2 aux
+
+   $mode->aux( $aux )->get
 
 Set the C<AUX> output pin level.
 
@@ -115,7 +123,9 @@ sub aux
    $self->_update_peripherals;
 }
 
-=head2 $mode->cs( $cs )->get
+=head2 cs
+
+   $mode->cs( $cs )->get
 
 Set the C<CS> output pin level.
 
