@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Device::BusPirate::Mode );
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 
@@ -80,7 +80,9 @@ sub start
    Future->done( $self );
 }
 
-=head2 $bb->configure( %args )->get
+=head2 configure
+
+   $bb->configure( %args )->get
 
 Change configuration options. The following options exist; all of which are
 simple true/false booleans.
@@ -108,15 +110,25 @@ sub configure
    return Future->done
 }
 
-=head2 $bb->cs( $state )->get
+=head2 cs
 
-=head2 $bb->miso( $state )->get
+=head2 miso
 
-=head2 $bb->clk( $state )->get
+=head2 clk
 
-=head2 $bb->mosi( $state )->get
+=head2 mosi
 
-=head2 $bb->aux( $state )->get
+=head2 aux
+
+   $bb->cs( $state )->get
+
+   $bb->miso( $state )->get
+
+   $bb->clk( $state )->get
+
+   $bb->mosi( $state )->get
+
+   $bb->aux( $state )->get
 
 Set an output pin to the given logical state. Uses the C<open_drain>
 configuration setting to determine whether high should be hi-Z or 3.3V.
@@ -129,7 +141,9 @@ sub clk  { shift->_write( 0, clk  => $_[0] ) }
 sub mosi { shift->_write( 0, mosi => $_[0] ) }
 sub aux  { shift->_write( 0, aux  => $_[0] ) }
 
-=head2 $bb->write( %pins )->get
+=head2 write
+
+   $bb->write( %pins )->get
 
 Sets the state of multiple output pins at the same time.
 
@@ -194,15 +208,25 @@ sub read_clk  { shift->_input1( MASK_CLK,  @_ ) }
 sub read_mosi { shift->_input1( MASK_MOSI, @_ ) }
 sub read_aux  { shift->_input1( MASK_AUX,  @_ ) }
 
-=head2 $state = $bb->read_cs->get
+=head2 read_cs
 
-=head2 $state = $bb->read_miso->get
+=head2 read_miso
 
-=head2 $state = $bb->read_clk->get
+=head2 read_clk
 
-=head2 $state = $bb->read_mosi->get
+=head2 read_mosi
 
-=head2 $state = $bb->read_aux->get
+=head2 read_aux
+
+   $state = $bb->read_cs->get
+
+   $state = $bb->read_miso->get
+
+   $state = $bb->read_clk->get
+
+   $state = $bb->read_mosi->get
+
+   $state = $bb->read_aux->get
 
 Set a pin to input direction and read its current state.
 
@@ -229,7 +253,9 @@ sub _input
    return $self->pirate->read( 1 );
 }
 
-=head2 $pins = $bbio->read->get
+=head2 read
+
+   $pins = $bbio->read->get
 
 Returns a HASH containing the current state of all the pins currently
 configured as inputs. More efficient than calling multiple C<read_*> methods
@@ -243,7 +269,9 @@ sub read
    $self->writeread();
 }
 
-=head2 $in_pins = $bbio->writeread( %out_pins )->get
+=head2 writeread
+
+   $in_pins = $bbio->writeread( %out_pins )->get
 
 Combines the effects of C<write> and C<read> in a single operation; sets the
 output state of any pins in C<%out_pins> then returns the input state of the
@@ -268,7 +296,9 @@ sub writeread
    });
 }
 
-=head2 $bb->power( $power )->get
+=head2 power
+
+   $bb->power( $power )->get
 
 Enable or disable the C<VREG> 5V and 3.3V power outputs.
 
@@ -285,7 +315,9 @@ sub power
    $self->pirate->read( 1 )->then_done(); # ignore input
 }
 
-=head2 $bb->pullup( $pullup )->get
+=head2 pullup
+
+   $bb->pullup( $pullup )->get
 
 Enable or disable the IO pin pullup resistors from C<Vpu>. These are connected
 to the C<MISO>, C<CLK>, C<MOSI> and C<CS> pins.
