@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Device::BusPirate::Mode );
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 
@@ -17,7 +17,7 @@ use Future::Utils qw( repeat );
 
 use constant MODE => "I2C";
 
-use constant PIRATE_DEBUG => $ENV{PIRATE_DEBUG};
+use constant PIRATE_DEBUG => $ENV{PIRATE_DEBUG} // 0;
 
 =head1 NAME
 
@@ -77,7 +77,59 @@ sub start
    });
 }
 
-=head2 $i2c->start_bit->get
+=head2 configure
+
+   $i2c->configure( %args )->get
+
+Change configuration options. The following options exist:
+
+=over 4
+
+=item speed
+
+A string giving the clock speed to use for I2C. Must be one of the values:
+
+ 5k 50k 100k 400k
+
+=back
+
+=cut
+
+my %SPEEDS = (
+   '5k'   => 0,
+   '50k'  => 1,
+   '100k' => 2,
+   '400k' => 3,
+);
+
+sub configure
+{
+   my $self = shift;
+   my %args = @_;
+
+   my $bytes = "";
+
+   if( defined $args{speed} ) {
+      my $speed = $SPEEDS{$args{speed}} or
+         croak "Unrecognised speed '$args{speed}'";
+
+      $bytes .= chr( 0x60 | $speed );
+   }
+
+   $self->pirate->write( $bytes );
+
+   $self->pirate->read( length $bytes, "I2C configure" )->then( sub {
+      my ( $response ) = @_;
+      $response eq "\x01" x length $bytes or
+         return Future->fail( "Expected ACK response to I2C configure" );
+
+      Future->done;
+   });
+}
+
+=head2 start_bit
+
+   $i2c->start_bit->get
 
 Sends an I2C START bit transition
 
@@ -94,7 +146,9 @@ sub start_bit
       ->else_fail( "Expected ACK response to I2C start_bit" );
 }
 
-=head2 $i2c->stop_bit->get
+=head2 stop_bit
+
+   $i2c->stop_bit->get
 
 Sends an I2C STOP bit transition
 
@@ -111,7 +165,9 @@ sub stop_bit
       ->else_fail( "Expected ACK response to I2C stop_bit" );
 }
 
-=head2 $i2c->write( $bytes )->get
+=head2 write
+
+   $i2c->write( $bytes )->get
 
 Sends the given bytes over the I2C wire. This method does I<not> send a
 preceding start or a following stop; you must do that yourself, or see the
@@ -141,7 +197,7 @@ sub write
          $self->pirate->read( length $bytes, "I2C write data" )
       })->then( sub {
          my ( $buf ) = @_;
-         $buf =~ m/^\x00+/;
+         $buf =~ m/^\x00*/;
          $+[0] == length $bytes and return Future->done;
          Future->fail( "Received NACK after $+[0] bytes" );
       });
@@ -150,7 +206,9 @@ sub write
      otherwise => sub { Future->done };
 }
 
-=head2 $bytes = $i2c->read( $length )->get
+=head2 read
+
+   $bytes = $i2c->read( $length )->get
 
 Receives the given number of bytes over the I2C wire, sending an ACK bit after
 each one but the final, to which is sent a NACK.
@@ -184,7 +242,9 @@ sub read
      };
 }
 
-=head2 $i2c->send( $address, $bytes )->get
+=head2 send
+
+   $i2c->send( $address, $bytes )->get
 
 A convenient wrapper around C<start_bit>, C<write> and C<stop_bit>. This
 method sends a START bit, then an initial byte to address the slave in WRITE
@@ -212,7 +272,9 @@ sub send
    });
 }
 
-=head2 $bytes = $i2c->recv( $address, $length )->get
+=head2 recv
+
+   $bytes = $i2c->recv( $address, $length )->get
 
 A convenient wrapper around C<start_bit>, C<write>, C<read> and C<stop_bit>.
 This method sends a START bit, then an initial byte to address the slave in
@@ -243,7 +305,9 @@ sub recv
    });
 }
 
-=head2 $bytes_in = $ic->send_then_recv( $address, $bytes_out, $read_len )->get
+=head2 send_then_recv
+
+   $bytes_in = $ic->send_then_recv( $address, $bytes_out, $read_len )->get
 
 A convenient wrapper around C<start_bit>, C<write>, C<read> and C<stop_bit>.
 This method combines a C<send> and C<recv> operation, with a repeated START
