@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Device::BusPirate::Mode );
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 
@@ -88,7 +88,9 @@ sub start
    });
 }
 
-=head2 $spi->configure( %args )->get
+=head2 configure
+
+   $spi->configure( %args )->get
 
 Change configuration options. The following options exist; all of which are
 simple true/false booleans.
@@ -198,7 +200,9 @@ sub configure
       ->else_fail( "Expected ACK response to SPI configure" );
 }
 
-=head2 $spi->chip_select( $cs )->get
+=head2 chip_select
+
+   $spi->chip_select( $cs )->get
 
 Set the C<CS> output pin level. A false value will pull it to ground. A true
 value will either pull it up to 3.3V or will leave it in a hi-Z state,
@@ -216,7 +220,9 @@ sub chip_select
       ->else_fail( "Expected ACK response to SPI chip_select" );
 }
 
-=head2 $miso_bytes = $spi->writeread( $mosi_bytes )->get
+=head2 writeread
+
+   $miso_bytes = $spi->writeread( $mosi_bytes )->get
 
 Performs an actual SPI data transfer. Writes bytes of data from C<$mosi_bytes>
 out of the C<MOSI> pin, while capturing bytes of input from the C<MISO> pin,
@@ -274,7 +280,9 @@ sub writeread
    });
 }
 
-=head2 $miso_bytes = $spi->writeread_cs( $mosi_bytes )->get
+=head2 writeread_cs
+
+   $miso_bytes = $spi->writeread_cs( $mosi_bytes )->get
 
 A convenience wrapper around C<writeread> which toggles the C<CS> pin before
 and afterwards. It uses the C<cs_high> configuration setting to determine the
